@@ -199,70 +199,3 @@ sub Option {
 
 __END__
 
-=head1 NAME
- 
-Parse::Eyapp::Options - Analysis of Options when parsing Eyapp grammars
- 
-=head1 SEE ALSO
-  
-Mostly legacy code.
-No documentation here. To learn about Parse::Eyapp::Options see the following
-documents:
-  
-=over
-
-=item * L<Parse::Eyapp>,
-
-=item * The tutorial I<Parsing Strings and Trees with> C<Parse::Eyapp>
-(An Introduction to Compiler Construction in seven pages)> in
-
-=item * The pdf file in L<http://nereida.deioc.ull.es/~pl/perlexamples/Eyapp.pdf> 
-
-=item * L<http://nereida.deioc.ull.es/~pl/perlexamples/section_eyappts.html> (Spanish),
-
-=item * L<eyapp>,
-
-=item * L<treereg>,
-
-=item * L<Parse::yapp>,
-
-=item * yacc(1),
-
-=item * bison(1),
-
-=item * The classic book "Compilers: Principles, Techniques, and Tools" by Alfred V. Aho, Ravi Sethi and
-
-=item * Jeffrey D. Ullman (Addison-Wesley 1986)
-
-=item * L<Parse::RecDescent>.
-
-=back
-
-=head1 AUTHOR
- 
-Casiano Rodriguez-Leon (casiano@ull.es)
- 
-=head1 ACKNOWLEDGMENTS
-
-This work has been supported by CEE (FEDER) and the Spanish Ministry of
-Educacin y Ciencia through Plan Nacional I+D+I number TIN2005-08818-C04-04
-(ULL::OPLINK project). Support from Gobierno de Canarias was through GC02210601
-(Grupos Consolidados).
-The University of La Laguna has also supported my work in many ways
-and for many years.
-I wish to thank Francois Desarmenien for his C<Parse::Yapp> module,
-to my students at La Laguna and to the Perl Community. Special thanks to
-my family and Larry Wall.
-
-=head1 LICENCE AND COPYRIGHT
-
-Copyright (c) 2006 Casiano Rodriguez-Leon (casiano@ull.es). All rights reserved.
-
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-
-
