@@ -1,6 +1,6 @@
 ###################################################################################
 #
-#    This file was generated using Parse::Eyapp version 1.092.
+#    This file was generated using Parse::Eyapp version 1.093.
 #
 # (c) Parse::Yapp Copyright 1998-2001 Francois Desarmenien.
 # (c) Parse::Eyapp Copyright 2006-2007 Casiano Rodriguez-Leon. Universidad de La Laguna.
@@ -236,7 +236,7 @@ sub new {
     and $class=ref($class);
 
     warn $warnmessage unless __PACKAGE__->isa('Parse::Eyapp::Driver'); 
-    my($self)=$class->SUPER::new( yyversion => '1.092',
+    my($self)=$class->SUPER::new( yyversion => '1.093',
                                   yyGRAMMAR  =>
 [
   [ _SUPERSTART => '$start', [ 'treeregexplist', '$end' ], 0 ],
@@ -1903,68 +1903,6 @@ sub Parse::Eyapp::Treeregexp::GLOBALCODE::translate {
          "$transform->[0]\n";
 };
 
-=head1 NAME
- 
-Parse::Eyapp::Treeregexp - Implements the translator of Tree Regular Expresions to Perl
- 
-=head1 SEE ALSO
-
-No documentation here. To learn about Parse::Eyapp::Treeregexp see:
-
-=over
-
-=item * L<Parse::Eyapp>,
-
-=item * L<http://nereida.deioc.ull.es/~pl/perlexamples/section_eyappts.html> (Spanish),
-
-=item * L<eyapp>,
-
-=item * L<treereg>,
-
-=item * L<Parse::Yapp>,
-
-=item * yacc(1),
-
-=item * bison(1),
-
-=item * The classic book 
-"Compilers: Principles, Techniques, and Tools" by Alfred V. Aho, Ravi Sethi and
-Jeffrey D. Ullman (Addison-Wesley 1986)
-
-=item * L<Parse::RecDescent>.
-
-=back
-
-=head1 AUTHOR
- 
-Casiano Rodriguez-Leon (casiano@ull.es)
- 
-=head1 ACKNOWLEDGMENTS
-
-This work has been supported by CEE (FEDER) and the Spanish Ministry of
-Educacin y Ciencia through Plan Nacional I+D+I number TIN2005-08818-C04-04
-(ULL::OPLINK project). Support from Gobierno de Canarias was through GC02210601
-(Grupos Consolidados).
-The University of La Laguna has also supported my work in many ways
-and for many years.
-I wish to thank Francois Desarmenien for his C<Parse::Yapp> module,
-to my students at La Laguna and to the Perl Community. Special thanks to
-my family and Larry Wall.
-
-=head1 LICENCE AND COPYRIGHT
-
-Copyright (c) 2006 Casiano Rodriguez-Leon (casiano@ull.es). All rights reserved.
-
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-
-=cut
-
-
 
 ################ @@@@@@@@@ End of User Code @@@@@@@@@ ###################
 
